@@ -7,4 +7,6 @@ from mail_factory import factory
 
 
 def registered_mails_names():
-    return zip(factory.mail_map.keys(), factory.mail_map.keys())
+    for k, v in factory._registry.items():
+        yield k, v.__name__
+    return
